/*************************************
 * Chrome Theme                      *
 * Author: nowrep                    *
 * Based on: Firefox Chromifox Theme *
 *************************************/

*[html-link-look="true"]
{
    color: palette(link);
    text-decoration: underline;
}

/*MainWindow*/
#mainwindow
{
    background: #e4edf9 url(images/toolbar-bg.png) repeat-x;
}

#mainwindow-menubar
{
    background: transparent;
    border: none;
}

#mainwindow-menubar:item
{
    color: black;
    spacing: 5px;
    padding: 2px 6px;
    background: transparent;
}

#mainwindow-menubar::item:pressed
{
    background-color: qlineargradient(x1:0, y1:0, x2:0, y2:1,stop:0 #a1c0e6, stop:1 #86abd9);
    border: 1px solid #4b6e99;
    border-top-left-radius: 4px;
    border-top-right-radius: 4px;
    border-bottom: none;
}

#mainwindow-statusbar
{
    background-color: #e4edf9;
}

#statusbar-ip-label
{
    padding-right: 5px;
}

/*NavigationBar*/
#navigationbar
{
    qproperty-layoutMargin: 3;
    qproperty-layoutSpacing: 3;
}

#navigationbar QSplitter::handle
{
    background-color:transparent;
}

#navigation-button-back
{
    qproperty-multiIcon: url(images/navigation-back.png);
}

#navigation-button-next
{
    qproperty-multiIcon: url(images/navigation-forward.png);
}

#navigation-button-stop
{
    qproperty-multiIcon: url(images/navigation-stop.png);
}

#navigation-button-reload
{
    qproperty-multiIcon: url(images/navigation-reload.png);
}

#navigation-button-home
{
    qproperty-multiIcon: url(images/navigation-home.png);
}

#navigation-button-addtab
{
    qproperty-multiIcon: url(images/navigation-addtab.png);
}

#navigation-button-tools
{
    qproperty-icon: url(images/navigation-tools.png);
}

#navigation-button-exitfullscreen
{
    qproperty-icon: url(images/navigation-exit-fullscreen.png);
}

#navigation-button-supermenu
{
    qproperty-multiIcon: url(images/navigation-supermenu.png);
}

#navigation-toolbutton-badge
{
    background: palette(dark);
    color: palette(bright-text);
    margin: 0px 1px;
}

ToolButton[button-id="button-downloads"]
{
    qproperty-icon: url(images/navigation-downloads.png);
}

ToolButton[toolbar-look="true"]
{
    qproperty-iconSize: 19px 19px;
    qproperty-fixedsize: 31px 29px;
    border-image: url(images/toolbutton.png);
}

ToolButton[toolbar-look="true"]:hover
{
    border-image: url(images/toolbutton-h.png);
}

ToolButton[toolbar-look="true"]:pressed
{
    border-image: url(images/toolbutton-a.png);
}

/*TabWidget*/
#tabbar
{
    qproperty-tabPadding: -1;
    qproperty-baseColor: 0;
}

#tabbar::scroller
{
    width: 0px;
}

#tabbar-button-right
{
    qproperty-icon: url(images/tab-right-arrow.png);
    qproperty-fixedsize: 15px 25px;
}

#tabbar-button-left
{
    qproperty-icon: url(images/tab-left-arrow.png);
    qproperty-fixedsize: 15px 25px;
}

#tabwidget-button-opentabs
{
    qproperty-multiIcon: url(images/tabs-list-button.png);
}

#tabwidget-button-closedtabs
{
    qproperty-multiIcon: url(images/tabs-closed-button.png);
}

#tabwidget-button-addtab
{
    qproperty-multiIcon: url(images/tabbar-addtab.png);
}

/*IconProvider*/
IconProvider
{
    qproperty-bookmarkIcon: url(images/star-a.png);
}

/*LocationBar*/
#locationbar
{
    background: transparent;
    border-image: url(images/lineedit-bg.png);
    border-width: 3px;
    color:black;
    padding-right: 0px;
    padding-left: 0px;
    padding-top: -2px;
    padding-bottom: -2px;
    qproperty-fixedheight: 27;
    qproperty-leftMargin: 28;
}

#locationbar-bookmarkicon
{
    margin-bottom: 2px;
    qproperty-pixmap: url(images/star.png);
}

#locationbar-bookmarkicon[bookmarked="true"]
{
    qproperty-pixmap: url(images/star-a.png);
}

#locationbar-siteicon
{
    border-image: url(images/siteicon-bg.png);
    qproperty-fixedsize:30px 27px;
    padding-left: 0px;
}

#locationbar-siteicon[secured="true"]
{
    border-image: url(images/siteicon-secure-bg.png);
}

#locationbar-goicon
{
    qproperty-pixmap: url(images/gotoaddress.png);
}

#locationbar-down-icon
{
    margin-bottom: 1px;
    qproperty-pixmap: url(images/navigation-dropdown.png);
}

#locationbar-autofillicon
{
    margin-bottom: 1px;
    qproperty-pixmap: url(images/key.png);
}

/*SideBar*/
#sidebar
{
    background: transparent;
}

#sidebar-splitter::handle
{
    background-color:transparent;
}

/*WebSearchBar*/
#websearchbar
{
    background: transparent;
    border-image: url(images/lineedit-bg.png);
    border-width: 3px;
    color:black;
    padding-right: 0px;
    padding-left: 0px;
    padding-top: -2px;
    padding-bottom: -2px;
    qproperty-fixedheight: 27;
    qproperty-leftMargin: 35;
}

#websearchbar-searchbutton
{
    margin-top: 2px;
    margin-right: 2px;
    qproperty-pixmap: url(images/search-icon.png);
}

#websearchbar-searchprovider-combobox
{
    border-image: url(images/searchbar-provider-bg.png);
    padding-left:-8px;
    qproperty-fixedsize: 37px 27px;
}

/*SearchToolbar*/
SearchToolBar #lineEdit[notfound="true"]
{
    background:#ff6666;
}

/*AboutDialog*/
AboutDialog #label
{
    background: palette(window);
}

AboutDialog #textLabel
{
    background: palette(window);
}

/*DesktopNotification*/
DesktopNotification
{
    background: #31363b;
}

DesktopNotification #frame
{
    border: 1px solid #696d71;
    padding: 10px;
}

DesktopNotification #heading
{
    font: bold;
    color: #c2c7c7;
}

DesktopNotification #text
{
    color: #e7ebeb;
}

/*BrowsingLibrary*/
BrowsingLibrary #tabs
{
    qproperty-bgPixmap: url(images/library-bg.png);
}

BrowsingLibrary #frame
{
    background: url(images/library-bg.png);
}

/*JavaScript Dialogs*/
#jsFrame
{
    background: url(images/semi-transp.png);
}

QFrame[js-frame="true"]
{
    border: 1px solid  black;
    border-bottom: 0px;
    background-color: white;
}

QFrame[js-frame2="true"]
{
    border: 1px solid  black;
    border-top: 0px;
    background-color: #f3f3f3;
}
